@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc-types
 version: 1.16.1
-id: pandoc-types-1.16.1-4cd1533070797f7596c108f3982c26c4
-key: pando_454MtrvEViEEUr9vMtnYwm
+id: pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
+key: pando_CzM4z0XNJTE7ZukSkA3G2L
 license: BSD3
 copyright: (c) 2006-2015 John MacFarlane
 maintainer: jgm@berkeley.edu
@@ -41,9 +41,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-types-1.16.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-types-1.16.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/pandoc-types-1.16.1
-hs-libraries: HSpandoc-types-1.16.1-454MtrvEViEEUr9vMtnYwm
+hs-libraries: HSpandoc-types-1.16.1-CzM4z0XNJTE7ZukSkA3G2L
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
